Welcome to Ldaptor's documentation!
===================================

What is Ldaptor
---------------

Ldaptor is a pure-Python Twisted library that implements:

- LDAP client and server logic
- separately-accessible LDAP and BER protocol message generation/parsing
- ASCII-format LDAP filter generation and parsing
- LDIF format data generation

Get it from `PyPI <https://pypi.python.org/pypi/Ldaptor>`_, find out what's new in the :doc:`NEWS`!

-----------
Quick Start
-----------

.. toctree::
    :maxdepth: 1

    quickstart

------------
User's Guide
------------

.. toctree::
   :maxdepth: 1

   ldap-intro
   simple-app 
   ldaptor

----------------
Ldaptor Cookbook
----------------

.. toctree::
   :maxdepth: 2

   cookbook

Meta
----

.. toctree::
   :maxdepth: 1

   NEWS
   status
   AUTHORS

   glossary

Indices and tables
==================

- :ref:`genindex`
- :ref:`modindex`
- :ref:`search`
